@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::PerlTidy;
 
 BEGIN {
-    $Dist::Zilla::Plugin::PerlTidy::VERSION = '0.09';
+    $Dist::Zilla::Plugin::PerlTidy::VERSION = '0.10';
 }
 
 # ABSTRACT: PerlTidy in Dist::Zilla
@@ -45,7 +45,9 @@ sub _munge_perl {
         ( $perltidyrc ? ( perltidyrc => $perltidyrc ) : () ),
     );
 
-    $file->content($destination);
+    ref($file) eq 'Dist::Zilla::File::FromCode'
+        ? $file->code($destination)
+        : $file->content($destination);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -63,7 +65,7 @@ Dist::Zilla::Plugin::PerlTidy - PerlTidy in Dist::Zilla
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 METHODS
 
@@ -94,12 +96,21 @@ L<Perl::Tidy>
 
 =head1 AUTHORS
 
-  Fayland Lam <fayland@gmail.com>
-  Mark Gardner <mjgardner@cpan.org>
+=over 4
+
+=item *
+
+Fayland Lam <fayland@gmail.com>
+
+=item *
+
+Mark Gardner <mjgardner@cpan.org>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Fayland Lam.
+This software is copyright (c) 2011 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
